# ISO Currency

A python library that provides custom helper classes for currencies.

## Installation

To install the library, you can use pip:

```bash
pip install iso4217-money
```


## TODO
- Documentation
- Review docstrings and comments all through the code
- Add tests
- Validation in github actions regarding the ISO 4217 standard and if some change broke certains assumptions
- Review Currency Formattings
- Add possible functionality of currency per country